@@ -293,7 +293,7 @@ def CLI():
 
         score.to_csv(args.outname + ".csv", sep="\t", header=True, index=False)
 
-        print(score.iloc[550:650,:])
+        #print(score.iloc[550:650,:])
         os.system("rm -rf MatrixTemp*")
 
     parser_samples = subparsers.add_parser("multisamples",help="The same metrics for muliple samples",
