@@ -6,12 +6,20 @@ chr=$3
 gt=$4
 outname=$5
 
-pwd=$(cd $(dirname $0) && pwd)
 
-echo Start dump matrix
+pwd=$(cd $(dirname $0) && pwd)
 chrnum=$(echo $chr |sed 's/chr//g')
-cooler dump -r $chr --join $cool | cut -f 2,5,7  > sparse.temp || cooler dump -r $chrnum --join $cool | cut -f 2,5,7 > sparse.temp
-echo Finish dump matrix
+chrlen=$(cooler dump -t chroms $cool |head -1 |cut -f 1 |awk '{print length}')
+echo $chrlen
+
+if [ $chrlen -gt 3 ]
+then
+  echo 'chang'
+  cooler dump -r $chr --join $cool | cut -f 2,5,7  > sparse.temp
+else
+  echo 'duan'
+  cooler dump -r $chrnum --join $cool | cut -f 2,5,7  > sparse.temp
+fi
 
 mkdir -p $outname/${binsize}
 
